==> haskell-logict-0.8.1.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 logict
version:              0.8.1.0
visibility:           public
id:                   logict-0.8.1.0-KdPj0Lj09QH5Js8BBzBwNR
key:                  logict-0.8.1.0-KdPj0Lj09QH5Js8BBzBwNR
license:              BSD-3-Clause
copyright:
    (c) 2007-2014 Dan Doel,
    (c) 2011-2013 Edward Kmett,
    (c) 2014      Roman Cheplyaka,
    (c) 2020-2021 Andrew Lelechenko,
    (c) 2020-2021 Kevin Quick

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    Adapted from the paper
    <http://okmij.org/ftp/papers/LogicT.pdf Backtracking, Interleaving, and Terminating Monad Transformers>
    by Oleg Kiselyov, Chung-chieh Shan, Daniel P. Friedman, Amr Sabry.

category:             Control
abi:                  b87bd1eac0a82f82a79eded6f41818b9
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-9.4.8/site-local/logict-0.8.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/logict-0.8.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/logict-0.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logict
hs-libraries:         HSlogict-0.8.1.0-KdPj0Lj09QH5Js8BBzBwNR
depends:              base-4.17.2.1 mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logict-0.8.1.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 logict
version:              0.8.1.0
visibility:           public
id:                   logict-0.8.1.0-FwG3mOkShN39MV5YyYDmPX
key:                  logict-0.8.1.0-FwG3mOkShN39MV5YyYDmPX
license:              BSD-3-Clause
copyright:
    (c) 2007-2014 Dan Doel,
    (c) 2011-2013 Edward Kmett,
    (c) 2014      Roman Cheplyaka,
    (c) 2020-2021 Andrew Lelechenko,
    (c) 2020-2021 Kevin Quick

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    Adapted from the paper
    <http://okmij.org/ftp/papers/LogicT.pdf Backtracking, Interleaving, and Terminating Monad Transformers>
    by Oleg Kiselyov, Chung-chieh Shan, Daniel P. Friedman, Amr Sabry.

category:             Control
abi:                  214aab62b3a7850494ebe97d9dd85644
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-9.4.8/site-local/logict-0.8.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/logict-0.8.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/logict-0.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logict
hs-libraries:         HSlogict-0.8.1.0-FwG3mOkShN39MV5YyYDmPX
depends:              base-4.17.2.1 mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
